/*
 * The MIT License
 *
 * Copyright 2017 Germán Bordel <german.bordel at ehu.es>.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package edu.upvehu.gbg.ejemplos.pvdb;

import java.io.IOException;
import java.sql.Connection;

import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.SQLException;

/**
 * Clase (ejemplo) para procesar ficheros de alineamientos del PV y llevar sus estadísticas a una base de datos
 *
 * @author Germán Bordel &lt;german.bordel at ehu.es&gt;
 */
public class EjemploPVDB {
    private static String directorio="http://gtts.ehu.es/German/Docencia/assets/";
    private static String[] identificadores={"20171201","20171211","20171214","20171215"};
    private static Connection conexion;
    static {
         try {
              conexion= DriverManager.getConnection("jdbc:mysql://localhost:3306/actaspv", "German", "chicle");
         } catch (SQLException ex) {
             System.err.println(ex.getMessage());
         }
    }
   
    public static void main(String[] args){
        if (conexion!=null) for (String id:identificadores) {
            try {
                ResultSet rs=conexion.createStatement().executeQuery(
                        String.format("select id from estadisticas where id = '%s'",id)
                );
                rs.last();
                if (rs.getRow()!=1) procesaFichero(id);
                else System.out.println(id+ " ya tiene estadístcas en la base de datos.");
            } catch (SQLException ex) {
                System.err.println("*** ERROR EN "+id+": "+ex.getMessage());
            }
        }
    }
    
    private static void procesaFichero(String id){
        try {
            Long t=System.currentTimeMillis();
            PVSession session=new PVSession(directorio+id+".txt");
            System.out.format("\nTiempo de Lectura de fichero %s: %d ms. Leidas %d palabras (%d fonemas)\n",
                    id,(System.currentTimeMillis()-t),session.getPalabras().size(),session.getFonemas().size());
            session.stats().dump2DB(conexion, id);
            System.out.println("Grabadas las estadísticas en la base de datos");
        } catch (IOException | SQLException ex) {
            System.err.println("*** ERROR EN "+id+": "+ex.getMessage());
        }
    }
}
